# Errors

```{eval-rst}
.. autoclass:: xanax.errors.XanaxError
   :members:
```

```{eval-rst}
.. autoclass:: xanax.errors.AuthenticationError
   :members:
```

```{eval-rst}
.. autoclass:: xanax.errors.RateLimitError
   :members:
```

```{eval-rst}
.. autoclass:: xanax.errors.NotFoundError
   :members:
```

```{eval-rst}
.. autoclass:: xanax.errors.ValidationError
   :members:
```

```{eval-rst}
.. autoclass:: xanax.errors.APIError
   :members:
```
